@@ -24,7 +24,9 @@ public slots:
 
 private:
     bool viewportEvent(QEvent *e);
+    void mousePressEvent(QMouseEvent *e);
     void mouseReleaseEvent(QMouseEvent *e);
+    void mouseMoveEvent(QMouseEvent *e);
 
     QDate date;
 
