@@ -1,17 +1,18 @@
 #ifndef DATEPICKDIALOG_H
 #define DATEPICKDIALOG_H
 
-#include "RotatingDialog.h"
-#include "ui_DatePickDialog.h"
+#include "DateTimePickDialog.h"
 
 #include <QListWidget>
 
 #include <QDate>
 
-class DatePickDialog : public RotatingDialog
+class DatePickDialog : public DateTimePickDialog
 {
     Q_OBJECT
 
+    using DateTimePickDialog::centerView;
+
 public:
     enum Type
     {
@@ -30,16 +31,14 @@ signals:
     void selected(QDate date);
 
 private:
-    Ui::DatePickDialog *ui;
-
     Type type;
 
-    QListWidget *lists[TypeCount];
+    QListWidget *dList;
+    QListWidget *wList;
+    QListWidget *mList;
+    QListWidget *yList;
 
-    int resizeCount;
-    void resizeEvent(QResizeEvent *e);
-
-    int row(Type type);
+    void setDate(const QDate &date);
 
     int day();
     int month();
@@ -50,6 +49,7 @@ private slots:
     void adjustDays();
     void adjustWeeks();
 
+    void reset();
     void accept();
 };
 
